@@ -18,5 +18,5 @@ from .portfolios import PortfoliosEntry
 from .gallery import GalleryEntry
 from .stream_content import StreamContentEntry
 from .gallery_slider import GallerySliderEntry
-from .pricing import PricingEntry
+from .pricing import PricingEntry, PricingDualEntry
 from .review import ReviewEntry
