@@ -1,21 +1,12 @@
-from wagtail.core import blocks
-
 from webspace.cms import constants
 from webspace.cms.blocks.common import \
-    TextBlock, \
-    EntryBlock
-
-
-class ClassicAccordionItem(blocks.StructBlock):
-    head = TextBlock(label="Head")
-    content = TextBlock(label="Head")
+    EntryBlock, \
+    AccordionBlock
 
 
 class AccordionEntry(EntryBlock):
     amp_scripts = ['accordion']
-    items = blocks.StreamBlock([
-        ('classic', ClassicAccordionItem()),
-    ], min_num=1)
+    items = AccordionBlock()
 
     def mock(self, *args, **kwargs):
         classic = {
