@@ -1,21 +1,11 @@
-from wagtail.core import blocks
-
 from webspace.cms import constants
 from webspace.cms.blocks.common import \
-    TextBlock, \
+    NumbersBlock, \
     EntryBlock
 
 
-class ClassicNumbersItem(blocks.StructBlock):
-    number = blocks.IntegerBlock(required=True)
-    unit = blocks.CharBlock(required=False, help_text='unité de mesure')
-    content = TextBlock(label="Content")
-
-
 class NumbersEntry(EntryBlock):
-    items = blocks.StreamBlock([
-        ('classic', ClassicNumbersItem()),
-    ], min_num=1)
+    items = NumbersBlock()
 
     def mock(self, *args, **kwargs):
         classic = {
