@@ -30,3 +30,13 @@ class PricingEntry(EntryBlock):
         template = '%s/entries/pricing.html' % constants.BLOCK_TEMPLATES_PATH
         label = "Pricing"
         icon = 'grip'
+
+
+class PricingDualEntry(EntryBlock):
+    card_1 = PricingItem()
+    card_2 = PricingItem()
+
+    class Meta:
+        template = '%s/entries/pricing_dual.html' % constants.BLOCK_TEMPLATES_PATH
+        label = "Pricing Dual"
+        icon = 'grip'
